==> SlimyBoyos-fabric-1.21.8-21.0.1-sources.jar: com/blamejared/slimyboyos/client/SlimeItemLayer.java <==
package com.blamejared.slimyboyos.client;

import com.blamejared.slimyboyos.api.IAbsorberRenderState;
import net.minecraft.class_10042;
import net.minecraft.class_10444;
import net.minecraft.class_3532;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_609;
import org.joml.Quaternionf;

public class SlimeItemLayer extends class_3887<class_10042, class_609> {
    
    public SlimeItemLayer(class_3883<class_10042, class_609> renderer) {
        
        super(renderer);
    }
    
    @Override
    public void render(class_4587 poseStack, class_4597 multiBufferSource, int i, class_10042 state, float yRot, float xRot) {
        
        if(!state.field_53333 && state instanceof IAbsorberRenderState abs) {
            class_10444 itemState = abs.slimyboyos$getAbsorbedItemState();
            if(itemState.method_65606()) {
                return;
            }
            poseStack.method_22903();
            poseStack.method_22907(new Quaternionf().rotateX(class_3532.field_29844));
            poseStack.method_46416(0, -1, 0);
            poseStack.method_22907(new Quaternionf().rotateX(class_3532.field_29844 / 2f).rotateY(abs.slimyboyos$getId() % 360));
            poseStack.method_22904(0, -(4 * 0.0626), 0);
            poseStack.method_22904(0, 0, -0.0626 / 4);
            poseStack.method_22907(new Quaternionf().rotateY(class_3532.field_29844 / 2f));
            itemState.method_65604(poseStack, multiBufferSource, i, class_4608.field_21444);
            
            poseStack.method_22909();
            
        }
    }
    
    
}

==> SlimyBoyos-fabric-1.21.11-24.0.1-sources.jar: com/blamejared/slimyboyos/client/SlimeItemLayer.java <==
package com.blamejared.slimyboyos.client;

import com.blamejared.slimyboyos.api.IAbsorberRenderState;
import net.minecraft.class_10042;
import net.minecraft.class_10444;
import net.minecraft.class_11659;
import net.minecraft.class_3532;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4608;
import net.minecraft.class_609;
import org.joml.Quaternionf;

public class SlimeItemLayer extends class_3887<class_10042, class_609> {
    
    public SlimeItemLayer(class_3883<class_10042, class_609> renderer) {
        
        super(renderer);
    }
    
    @Override
    public void submit(class_4587 poseStack, class_11659 collector, int i, class_10042 state, float yRot, float xRot) {
        
        if(!state.field_53333 && state instanceof IAbsorberRenderState abs) {
            class_10444 itemState = abs.slimyboyos$getAbsorbedItemState();
            if(itemState.method_65606()) {
                return;
            }
            poseStack.method_22903();
            poseStack.method_22907(new Quaternionf().rotateX(class_3532.field_29844));
            poseStack.method_46416(0, -1, 0);
            poseStack.method_22907(new Quaternionf().rotateX(class_3532.field_29844 / 2f).rotateY(abs.slimyboyos$getId() % 360));
            poseStack.method_22904(0, -(4 * 0.0626), 0);
            poseStack.method_22904(0, 0, -0.0626 / 4);
            poseStack.method_22907(new Quaternionf().rotateY(class_3532.field_29844 / 2f));
            itemState.method_65604(poseStack, collector, i, class_4608.field_21444, state.field_61821);
            
            poseStack.method_22909();
            
        }
    }
    
}
